@@ -2,7 +2,6 @@ from guardian.compat import include, url, handler404, handler500
 from django.conf import settings
 from django.contrib import admin
 from django.contrib.auth.views import logout
-from django.conf.urls import url
 
 __all__ = ['handler404', 'handler500']
 
@@ -12,6 +11,7 @@ admin.autodiscover()
 urlpatterns = [
     url(r'^admin/', include(admin.site.urls)),
     url(r'^logout/$', logout, {'next_page': '/'}, name='logout'),
+    url(r'^article/', include('articles.urls', namespace='articles')),
     url(r'^', include('posts.urls')),
 ]
 
