@@ -69,18 +69,43 @@ class AssignPermTest(ObjectPermissionTestCase):
                           user_or_group=self.user)
 
     def test_user_assign_perm(self):
-        assign_perm("change_contenttype", self.user, self.ctype)
+        assign_perm("add_contenttype", self.user, self.ctype)
         assign_perm("change_contenttype", self.group, self.ctype)
+        assign_perm(self.get_permission("delete_contenttype"), self.user, self.ctype)
+        self.assertTrue(self.user.has_perm("add_contenttype", self.ctype))
         self.assertTrue(self.user.has_perm("change_contenttype", self.ctype))
+        self.assertTrue(self.user.has_perm("delete_contenttype", self.ctype))
 
     def test_group_assign_perm(self):
+        assign_perm("add_contenttype", self.group, self.ctype)
         assign_perm("change_contenttype", self.group, self.ctype)
-        assign_perm("delete_contenttype", self.group, self.ctype)
+        assign_perm(self.get_permission("delete_contenttype"), self.group, self.ctype)
 
         check = ObjectPermissionChecker(self.group)
+        self.assertTrue(check.has_perm("add_contenttype", self.ctype))
         self.assertTrue(check.has_perm("change_contenttype", self.ctype))
         self.assertTrue(check.has_perm("delete_contenttype", self.ctype))
 
+    def test_user_assign_perm_queryset(self):
+        assign_perm("add_contenttype", self.user, self.ctype_qset)
+        assign_perm("change_contenttype", self.group, self.ctype_qset)
+        assign_perm(self.get_permission("delete_contenttype"), self.user, self.ctype_qset)
+        for obj in self.ctype_qset:
+            self.assertTrue(self.user.has_perm("add_contenttype", obj))
+            self.assertTrue(self.user.has_perm("change_contenttype", obj))
+            self.assertTrue(self.user.has_perm("delete_contenttype", obj))
+
+    def test_group_assign_perm_queryset(self):
+        assign_perm("add_contenttype", self.group, self.ctype_qset)
+        assign_perm("change_contenttype", self.group, self.ctype_qset)
+        assign_perm(self.get_permission("delete_contenttype"), self.group, self.ctype_qset)
+
+        check = ObjectPermissionChecker(self.group)
+        for obj in self.ctype_qset:
+            self.assertTrue(check.has_perm("add_contenttype", obj))
+            self.assertTrue(check.has_perm("change_contenttype", obj))
+            self.assertTrue(check.has_perm("delete_contenttype", obj))
+
     def test_user_assign_perm_global(self):
         perm = assign_perm("contenttypes.change_contenttype", self.user)
         self.assertTrue(self.user.has_perm("contenttypes.change_contenttype"))
@@ -130,6 +155,20 @@ class RemovePermTest(ObjectPermissionTestCase):
         check = ObjectPermissionChecker(self.group)
         self.assertFalse(check.has_perm("change_contenttype", self.ctype))
 
+    def test_user_remove_perm_queryset(self):
+        assign_perm("change_contenttype", self.user, self.ctype_qset)
+        remove_perm("change_contenttype", self.user, self.ctype_qset)
+        for obj in self.ctype_qset:
+            self.assertFalse(self.user.has_perm("change_contenttype", obj))
+
+    def test_group_remove_perm_queryset(self):
+        assign_perm("change_contenttype", self.group, self.ctype_qset)
+        remove_perm("change_contenttype", self.group, self.ctype_qset)
+
+        check = ObjectPermissionChecker(self.group)
+        for obj in self.ctype_qset:
+            self.assertFalse(check.has_perm("change_contenttype", obj))
+
     def test_user_remove_perm_global(self):
         # assign perm first
         perm = "contenttypes.change_contenttype"
